# -*- coding: utf-8 -*-

from __future__ import division

from django_logit import logit
from django_query import get_query_value
from django_response import response
from paginator import pagination
from TimeConvert import TimeConvert as tc

from equipment.models import IsolationPointInfo, IsolationPointUserInfo, ThermometerEquipmentInfo
from utils.error.errno_utils import IsolationPointStatusCode


@logit
def get_point_list(request):
    page = request.POST.get('page', 1)
    num = request.POST.get('num', 20)

    points = IsolationPointInfo.objects.filter(status=True)
    points, left = pagination(points, page, num)
    points = [point.data for point in points]

    return response(data={
        'points': points,
        'left': left,
    })


@logit
def get_point_info(request):
    point_id = request.POST.get('point_id', '')

    try:
        point = IsolationPointInfo.objects.get(point_id=point_id, status=True)
    except IsolationPointInfo.DoesNotExist:
        return response(IsolationPointStatusCode.ISOLATIONPOINT_NOT_FOUND)

    return response(data=point.data)


@logit
def update_point_info(request):
    point_id = request.POST.get('point_id', '')
    upload_period = get_query_value(request, 'upload_period', val_cast_type='listjson')

    IsolationPointInfo.objects.filter(point_id=point_id).update(point_upload_period=upload_period)

    return response()


@logit
def get_point_fields(request):
    point_id = request.POST.get('point_id', '')
    user_id = request.POST.get('user_id', '')

    try:
        point = IsolationPointInfo.objects.get(point_id=point_id, status=True)
    except IsolationPointInfo.DoesNotExist:
        return response(IsolationPointStatusCode.ISOLATIONPOINT_NOT_FOUND)

    try:
        ipui = IsolationPointUserInfo.objects.get(user_id=user_id, point_id=point_id)
    except IsolationPointUserInfo.DoesNotExist:
        ipui = None

    return response(data={
        'point_name': point.point_name,
        'fields': point.point_fields,
        'user_info': ipui.fields if ipui else [],
    })


@logit
def save_point_fields(request):
    point_id = request.POST.get('point_id', '')
    user_id = request.POST.get('user_id', '')
    fields = get_query_value(request, 'fields', val_cast_type='listjson')

    IsolationPointUserInfo.objects.update_or_create(point_id=point_id, user_id=user_id, defaults={
        'fields': fields,
        'status': True,
    })

    return response()


@logit
def bind_eqpt(request):
    macid = request.POST.get('macid', '')
    user_id = request.POST.get('user_id', '')

    try:
        ipui = IsolationPointUserInfo.objects.get(user_id=user_id, status=True)
    except IsolationPointUserInfo.DoesNotExist:
        return response(IsolationPointStatusCode.ISOLATIONPOINT_USER_NOT_FOUND)

    # 清除之前绑定的设备
    ThermometerEquipmentInfo.objects.filter(ipui_pk=ipui.pk).update(ipui_pk=0, active_status=ThermometerEquipmentInfo.OFFLINE)

    eqpt, _ = ThermometerEquipmentInfo.objects.update_or_create(macid=macid, defaults={
        'point_id': ipui.point_id,
        'ipui_pk': ipui.pk,
        'active_status': ThermometerEquipmentInfo.ONLINE,
        'active_at': tc.utc_datetime()
    })

    eqpt.ipui_pks += [ipui.pk]
    eqpt.save()

    ipui.eqpts += [macid]
    ipui.save()

    return response()
